@@ -19,7 +19,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(CONFIG CONFIG_module);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 our (%CONFIG, $IS_TEST, $IS_TEST_CONFIG, %SIGNO, $CONFIG_FILE);
 
@@ -323,8 +323,8 @@ Dynamic configuration signals:
             $Forks::Super::MAX_PROC ||= 1;
             print STDERR "MAX_PROC changed to $Forks::Super::MAX_PROC\n";
         } else {
-            print STDERR
-                "\$Forks::Super::MAX_PROC is a coderef. Unable to decrement\n"; 
+            print STDERR "\$Forks::Super::MAX_PROC is a coderef. ",
+                "Unable to decrement\n"; 
         }
     };
     $XSIG{$config_sig[4]}[1] = sub { Forks::Super::Debug::parent_dump(0); };
