@@ -28,7 +28,7 @@ eval 'use Devel::GlobalDestruction';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
                  POSTFORK_PARENT POSTFORK_CHILD);
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -330,7 +330,9 @@ sub _can_launch_delayed_start_check {
     return 1 if !defined($job->{start_after}) ||
 	Time::HiRes::time() >= $job->{start_after};
 
-    debug('_can_launch(): start delay requested. launch fail') if $job->{debug};
+    if ($job->{debug}) {
+        debug('_can_launch(): start delay requested. launch fail');
+    }
 
     # delay option should normally be associated with queue on busy behavior.
     # any reason not to make this the default ?
@@ -606,7 +608,8 @@ sub _robust_fork {
     my $job = shift;
     my $retries = $job->{retries} || 0;
 
-    # the other 21,000 lines in this distro are just a wrapper around this line:
+    # the other 18,000 lines in this distro
+    # are just a wrapper around this line:
 
     my $pid = _CORE_fork();
 
@@ -847,7 +850,7 @@ sub _postlaunch_daemon_child {
     my $p1 = $$;
     my $p2 = _CORE_fork();
     if ($p1 != $$) {
-	# the second child (daemon)
+	# the second child (daemon) (6., 7., & 8.)
 	return $job->_postlaunch_daemon_grandchild;
     }
 
@@ -907,11 +910,11 @@ sub _postlaunch_daemon_grandchild {
 
 sub _chdir_for_daemon {
     my ($job,$dir) = @_;
-    if (!defined($dir) || !chdir $dir) {
-	if (defined $dir) {
-	    carp '"Forks::Super::Job: failed to change daemon process ',
+    if (!defined($dir)) {
+        chdir '/';
+    } elsif (!chdir $dir) {
+        carp '"Forks::Super::Job: failed to change daemon process ',
 	        "directory to \"$dir\":", $!;
-	}
 	chdir '/';
     }
     return;
@@ -938,11 +941,6 @@ sub __adjust_cygwin_daemon_job {
 
 sub _postlaunch_child {
     my $job = shift;
-
-    local *STDIN = *STDIN;
-    local *STDOUT = *STDOUT;
-    local *STDERR = *STDERR;
-
     Forks::Super::init_child() unless $job->{is_emulation};
     $job->_config_child;
 
@@ -1183,7 +1181,9 @@ sub _postlaunch_child_to_sub {
     my $error;
     eval {
 	no strict 'refs';
-	$job->{_cleanup_code} = \&deinit_child;
+        if (!$job->{is_emulation}) {
+            $job->{_cleanup_code} = \&deinit_child;
+        }
 	$sub->(@args);
 	delete $job->{_cleanup_code};
 	1;
@@ -1198,6 +1198,7 @@ sub _postlaunch_child_to_sub {
 	debug("Job $$ subroutine call has completed");
     }
     if ($job->{is_emulation}) {
+        Forks::Super::Job::Ipc::_child_share($job);
         my $status = 0;
         if ($error) {
             $job->{error} = $error;
@@ -2326,7 +2327,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.81
+0.82
 
 =head1 SYNOPSIS
 
