@@ -33,7 +33,7 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 our $NO_README = 0;
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
@@ -647,6 +647,10 @@ sub retrieve_share {
 	# carp ...
 	return;
     }
+    if ($job->{is_emulation}) {
+        # job ran in foreground, values are already shared
+        return;
+    }
     my $VAR1 = '';
     my $fh;
     for my $try (1..10) {
@@ -659,7 +663,7 @@ sub retrieve_share {
     if ($job->{untaint}) {
 	($expr) = $expr =~ /(.*)/s;
     }
-    eval $expr;                   ## no critic (StringyEval,CheckingReturnValue)
+    eval $expr;               ## no critic (StringyEval,CheckingReturnValue)
     my @VAR1;
 
     if (ref $VAR1 eq 'ARRAY') {
@@ -963,15 +967,18 @@ sub _identify_shared_fh_dir {
 	    'C:/Winnt/Temp', 'D:/Windows/Temp', 'D:/Winnt/Temp',
 	    'E:/Windows/Temp', 'E:/Winnt/Temp', '.';
     } else {
-	# XXX - safe to untaint cwd?
 	my ($cwd) = Forks::Super::Util::abs_path('.') =~ /(.*)/;
 	unshift @search_dirs, $cwd;
-	push @search_dirs, '/tmp', '/var/tmp';
+	push @search_dirs, '/tmp', '/var/tmp', '/usr/tmp';
     }
 
     foreach my $dir (@search_dirs) {
 	next if !(defined($dir) && $dir =~ /\S/);
 	debug("Considering $dir as shared file handle dir ...") if $DEBUG;
+        if (! -w $dir || ! -x $dir || ! -r $dir) {
+            $DEBUG && debug("Bad permissions for $dir");
+            next;
+        }
 	if (Forks::Super::Config::configif('filehandles')) {
 	    if (set_ipc_dir($dir,0)) {
 		debug("Selected $_IPC_DIR as shared file handle dir ...")
@@ -3251,25 +3258,30 @@ sub init_child {
     return;
 }
 
+sub _child_share {
+    my $job = shift;
+    return if !defined $job->{share};
+    return if !defined $job->{share_ipc};
+    if (open my $fh, '>', $job->{share_ipc}) {
+        print $fh Data::Dumper::Dumper( $job->{share} );
+        close $fh;
+        if ($job->{debug}) {
+            debug("shared data written to $job->{share_ipc}");
+        }
+    } else {
+        carp 'Forks::Super::deinit_child: could not open ',
+            "share ipc file $job->{share_ipc}: $!";
+    }
+}
+
 sub deinit_child {
     use Data::Dumper;
     my $job = Forks::Super::Job->this;
     if ($job->{is_emulation}) {
         local *STDERR = *$Forks::Super::Debug::DEBUG_FH;
-        Carp::cluck("ZZZZ deinit_child called for emulated job!");
-    }
-    if (defined($job->{share}) && defined($job->{share_ipc})) {
-	if (open my $fh, '>', $job->{share_ipc}) {
-	    print $fh Data::Dumper::Dumper( $job->{share} );
-	    close $fh;
-	    if ($job->{debug}) {
-		debug("shared data written to $job->{share_ipc}");
-	    }
-	} else {
-	    carp 'Forks::Super::deinit_child: could not open ',
-	        "share ipc file $job->{share_ipc}: $!";
-	}
+        Carp::cluck("FSJ::Ipc: deinit_child called for emulated job!");
     }
+    _child_share($job);
 
     if (@IPC_FILES > 0) {
         Carp::cluck("Child $$ had temp files! @IPC_FILES\n")
@@ -3331,7 +3343,7 @@ Forks::Super::Job::Ipc - interprocess communication routines for Forks::Super
 
 =head1 VERSION
 
-0.81
+0.82
 
 =head1 DESCRIPTION
 
