@@ -14,7 +14,7 @@ use strict;
 use warnings;
 require Forks::Super::Job::OS::Win32 if &IS_WIN32 || &IS_CYGWIN;
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 our $CPU_AFFINITY_CALLS = 0;
 our $OS_PRIORITY_CALLS = 0;
@@ -23,9 +23,12 @@ sub _preconfig_os {
     my $job = shift;
     if (defined $job->{cpu_affinity}) {
         $job->{cpu_affinity_call} = ++$CPU_AFFINITY_CALLS;
+        $job->{cpu_affinity_orig} =
+            CONFIG('Sys::CpuAffinity') ? Sys::CpuAffinity::getAffinity($$):-1;
     }
     if (defined $job->{os_priority}) {
         $job->{os_priority_call} = ++$OS_PRIORITY_CALLS;
+        $job->{os_priority_orig} = get_os_priority($job);
     }
     return;
 }
@@ -68,6 +71,20 @@ sub Forks::Super::Job::_config_os_child {
     return;
 }
 
+sub get_os_priority {
+    my ($job) = @_;
+    local $@ = undef;
+    my $z = eval { getpriority(0,0) };
+    return $z if !$@;
+    if (&IS_WIN32) {
+        if (CONFIG('Win32::API')) {
+            require Forks::Super::Job::OS::Win32;
+            return Forks::Super::Job::OS::Win32::get_priority($job);
+        }
+    }
+    return -1;
+}
+
 sub set_os_priority {
     my ($job) = @_;
     my $priority = $job->{os_priority} || 0;
@@ -339,18 +356,17 @@ sub poor_mans_alarm {
     }
 
     # program to monitor a pid:
-    my $z = "PMA($pid,$time)";
-    my $prog = "\$0='$z';sleep 1,kill(0,$pid)||exit for 1..$time;kill -9,$pid";
+    my ($z,$p,$t) = ("PMA($pid,$time)",$pid,$time);
+    my $prog = "\$0='$z';sleep 1,kill(0,$p)||exit for 1..$t;kill -9,$p";
 
 #   my ($p,$t) = ($pid,$time);
-#   my $prog = "\$0='PMA($p,$t)';sleep 1,kill(0,$p)||exit for 1..$t;kill -9,$p";
+#   my $prog="\$0='PMA($p,$t)';sleep 1,kill(0,$p)||exit for 1..$t;kill -9,$p";
 
     if (&IS_WIN32) {
 	$prog .= ";system 'taskkill /f /pid $pid >nul'";
 	my $pma_pid = system 1, qq[$^X -e "$prog"];
 	if ($Forks::Super::Debug::DEBUG) {
-	    Forks::Super::Debug::DEBUG(
-                "set poor man's alarm for $pid/$time in process $pma_pid");
+	    debug("set poor man's alarm for $pid/$time in process $pma_pid");
 	}
 	return $pma_pid;
     } else {
