@@ -17,7 +17,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(queue_job);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 # must sync FIRST_DEFERRED_ID with Win32 code in Forks::Super::Util::isValidPid
 use constant FIRST_DEFERRED_ID => -500000;
@@ -533,11 +533,12 @@ Forks::Super::Queue
 
 =head1 VERSION
 
-0.81
+0.82
 
 =head1 DESCRIPTION
 
-C<Forks::Super::Queue> is part of the L<Forks::Super|Forks::Super> distribution.
+C<Forks::Super::Queue> is part of the L<Forks::Super|Forks::Super> 
+distribution.
 The function and variables in this module manage the queue
 of L<"deferred processes"|Forks::Super/"Deferred processes"> --
 background tasks that have been specified but that can not or 
