@@ -3,7 +3,8 @@ use strict;
 use warnings;
 use Carp;
 use Time::HiRes;
-our $VERSION = '0.81';
+use Forks::Super::Util;
+our $VERSION = '0.82';
 our @ISA = qw(Forks::Super::Sync);
 
 my $ipc_seq = 0;
@@ -144,6 +145,24 @@ sub DESTROY {
 
 sub _get_filename {
     no warnings 'once';
+    # best if this file is not on an NFS filesystem
+    my @dirs;
+    if ($^O eq 'MSWin32') {
+        @dirs = ('C:/Temp', 'C:/Windows/Temp',
+                 'C:/Winnt/Temp', 'D:/Windows/Temp', 'D:/Winnt/Temp',
+                 'E:/Windows/Temp', 'E:/Winnt/Temp', $ENV{TEMP}, '.');
+    } else {
+	my ($cwd) = Forks::Super::Util::abs_path('.');
+        @dirs = ('/tmp', '/var/tmp', '/usr/tmp', $cwd);
+    }
+    foreach my $dir (@dirs, $Forks::Super::IPC_DIR) {
+        if ($dir =~ /\S/ && -d $dir && -r $dir && -w $dir && -x $dir) {
+            return sprintf "%s/_sync%d-%03d",
+                           $dir, $Forks::Super::MAIN_PID || $$, $ipc_seq++;
+        }
+    }
+    carp "Forks::Super::Sync::Semaphlock: ",
+        "trouble finding suitable lockfile dir";
     return sprintf "%s/.sync%03d", $Forks::Super::IPC_DIR, $ipc_seq++;
 }
 
