@@ -21,7 +21,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wait waitpid waitall TIMEOUT WREAP_BG_OK);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 my ($productive_waitpid_code);
 my $respect_SIGCHLD_ignore = 1;
@@ -302,7 +302,8 @@ sub __waitpid_result {
 }
 
 sub _activate_one_suspended_job {
-    my @suspended = grep { $_->{state} eq 'SUSPENDED' } @Forks::Super::ALL_JOBS;
+    my @suspended =
+        grep { $_->{state} eq 'SUSPENDED' } @Forks::Super::ALL_JOBS;
     if (@suspended == 0) {
 	@suspended = grep { 
 	    $_->{state} =~ /SUSPENDED/
@@ -531,7 +532,7 @@ Forks::Super::Wait
 
 =head1 VERSION
 
-0.81
+0.82
 
 =head1 DESCRIPTION
 
